==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/PriceVolumeTrendIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { PriceVolumeTrendIndicatorDescription } from "./PriceVolumeTrendIndicatorDescription";
/**
 * @hidden
 */
export let PriceVolumeTrendIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class PriceVolumeTrendIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (PriceVolumeTrendIndicatorDescriptionMetadata.a == null) {
                PriceVolumeTrendIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PriceVolumeTrendIndicatorDescriptionMetadata.c(PriceVolumeTrendIndicatorDescriptionMetadata.a);
            }
            if (a.j(PriceVolumeTrendIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.y(PriceVolumeTrendIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
        }
        static d(a) {
            PriceVolumeTrendIndicatorDescriptionMetadata.b(a);
            a.aa("PriceVolumeTrendIndicator", () => new PriceVolumeTrendIndicatorDescription());
            a.z("PriceVolumeTrendIndicator", PriceVolumeTrendIndicatorDescriptionMetadata.a);
        }
    }
    PriceVolumeTrendIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(PriceVolumeTrendIndicatorDescriptionMetadata, 'PriceVolumeTrendIndicatorDescriptionMetadata');
    PriceVolumeTrendIndicatorDescriptionMetadata.a = null;
    return PriceVolumeTrendIndicatorDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/PriceVolumeTrendIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { PriceVolumeTrendIndicatorDescription } from "./PriceVolumeTrendIndicatorDescription";
/**
 * @hidden
 */
export let PriceVolumeTrendIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class PriceVolumeTrendIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (PriceVolumeTrendIndicatorDescriptionMetadata.a == null) {
                PriceVolumeTrendIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PriceVolumeTrendIndicatorDescriptionMetadata.c(PriceVolumeTrendIndicatorDescriptionMetadata.a);
            }
            if (a.k(PriceVolumeTrendIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.aa(PriceVolumeTrendIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
        }
        static d(a) {
            PriceVolumeTrendIndicatorDescriptionMetadata.b(a);
            a.ac("PriceVolumeTrendIndicator", () => new PriceVolumeTrendIndicatorDescription());
            a.ab("PriceVolumeTrendIndicator", PriceVolumeTrendIndicatorDescriptionMetadata.a);
        }
    }
    PriceVolumeTrendIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(PriceVolumeTrendIndicatorDescriptionMetadata, 'PriceVolumeTrendIndicatorDescriptionMetadata');
    PriceVolumeTrendIndicatorDescriptionMetadata.a = null;
    return PriceVolumeTrendIndicatorDescriptionMetadata;
})();
